pub(crate) const unsafe fn drop_glue<T>(_: &mut T)where
T: PointeeSized,Expand description
Helper function for drop_in_place. The compiler replaces this by the actual drop glue.
pub(crate) const unsafe fn drop_glue<T>(_: &mut T)where
T: PointeeSized,Helper function for drop_in_place. The compiler replaces this by the actual drop glue.